@@ -299,6 +299,9 @@ select nvl(NULL::text, 'B');
 select nvl(NULL::text, NULL);
 select nvl(1, 2);
 select nvl(NULL::int, 2);
+select nvl(NULL::double precision, 1);
+select nvl(1.1::double precision, 1);
+select nvl(1.1::numeric, 1);
 select nvl2('A'::text, 'B', 'C');
 select nvl2(NULL::text, 'B', 'C');
 select nvl2('A'::text, NULL, 'C');
